@@ -20,8 +20,6 @@ def _load_C_extension():
     this_dir = os.path.join(this_dir, "csrc")
     source = glob.glob(os.path.join(this_dir, "*.cpp"))
     source = [os.path.join(this_dir, s) for s in source]
-    print("source: {0}".format(source))
-    print("this_dir: {0}".format(this_dir))
     extra_include_paths = [this_dir]
     return load("svp_cpp", source, extra_include_paths=extra_include_paths)
 
