@@ -196,8 +196,8 @@ class SVPNet(torch.nn.Module):
         # process params and get set
         try:
             c = int(params["c"])
-        except ValueError:
-            raise ValueError(
+        except TypeError:
+            raise TypeError(
                 "Invalid representation complexity {0}. Must be integer.".format(
                     params["c"]
                 )
@@ -213,8 +213,8 @@ class SVPNet(torch.nn.Module):
         if params["svptype"] == "fb":
             try:
                 beta = int(params["beta"])
-            except ValueError:
-                raise ValueError(
+            except TypeError:
+                raise TypeError(
                     "Invalid beta {0}. Must be positive integer.".format(params["beta"])
                 )
             o_t = self.SVP.predict_set_fb(x, beta, c)
@@ -222,8 +222,8 @@ class SVPNet(torch.nn.Module):
             try:
                 delta = float(params["delta"])
                 gamma = float(params["gamma"])
-            except ValueError:
-                raise ValueError(
+            except TypeError:
+                raise TypeError(
                     "Invalid delta {0} or gamma {1}. Must be positive float.".format(
                         params["delta"], params["gamma"]
                     )
@@ -232,23 +232,23 @@ class SVPNet(torch.nn.Module):
         elif params["svptype"] == "sizectrl":
             try:
                 size = int(params["size"])
-            except ValueError:
-                raise ValueError(
+            except TypeError:
+                raise TypeError(
                     "Invalid size {0}. Must be positive integer.".format(params["size"])
                 )
             o_t = self.SVP.predict_set_size(x, size, c)
         elif params["svptype"] == "errorctrl":
             try:
                 error = float(params["error"])
-            except ValueError:
-                raise ValueError(
+            except TypeError:
+                raise TypeError(
                     "Invalid error {0}. Must be a real number in [0,1].".format(
                         params["error"]
                     )
                 )
             o_t = self.SVP.predict_set_error(x, error, c)
         else:
-            raise ValueError(
+            raise TypeError(
                 "Invalid SVP type {0}! Valid options: {fb, dg, sizectrl, errorctrl}.".format(
                     params["svptype"]
                 )
@@ -290,10 +290,10 @@ class SVPClassifier(BaseEstimator, ClassifierMixin):
         Min and max number of children a node can have in the random generated tree. Is only used when hierarchy='random'.
     n_jobs : int, default=1
         The number of jobs to run in parallel.
-    verbose : int, default=0
-        Controls the verbosity: the higher, the more messages.
     random_state_ : RandomState or an int seed, default=None
         A random number generator instance to define the state of the random generator.
+    verbose : int, default=0
+        Controls the verbosity: the higher, the more messages.
     X_ : {array-like, sparse matrix}, shape (n_samples, n_features)
         Training input samples seen during fit.
     y_ : array-like, shape (n_samples,)
@@ -405,7 +405,7 @@ class SVPClassifier(BaseEstimator, ClassifierMixin):
         X : {array-like, sparse matrix}, shape (n_samples, n_features)
             The training input samples.
         y : array-like, shape (n_samples,)
-            The class labels
+            The class labels.
 
         Returns
         -------
@@ -555,9 +555,8 @@ class SVPClassifier(BaseEstimator, ClassifierMixin):
         if not hasattr(self.estimator, "predict_proba"):
             # check whether the base estimator supports class scores
             if not hasattr(self.estimator, "decision_function"):
-                raise NotFittedError(
-                    "{0} does not support \
-                         probabilistic predictions nor scores.".format(
+                raise RuntimeError(
+                    "{0} does not support probabilistic predictions nor scores.".format(
                         self.estimator
                     )
                 )
@@ -584,9 +583,7 @@ class SVPClassifier(BaseEstimator, ClassifierMixin):
                     )
         except NotFittedError as e:
             raise NotFittedError(
-                "Error {}, this model is not fitted yet. Cal 'fit' \
-                    with appropriate arguments before using this \
-                    method.".format(
+                "Error {}, this model is not fitted yet. Cal 'fit' with appropriate arguments before using this method.".format(
                     e
                 )
             )
@@ -640,9 +637,8 @@ class SVPClassifier(BaseEstimator, ClassifierMixin):
         if not hasattr(self.estimator, "predict_proba"):
             # check whether the base estimator supports class scores
             if not hasattr(self.estimator, "decision_function"):
-                raise NotFittedError(
-                    "{0} does not support \
-                         probabilistic predictions nor scores.".format(
+                raise RuntimeError(
+                    "{0} does not support probabilistic predictions nor scores.".format(
                         self.estimator
                     )
                 )
@@ -679,9 +675,7 @@ class SVPClassifier(BaseEstimator, ClassifierMixin):
                             nodes_to_visit.append((self.tree_[c], parent_prob))
             except NotFittedError as e:
                 raise NotFittedError(
-                    "Error {}, this model is not fitted yet. Cal 'fit' \
-                        with appropriate arguments before using this \
-                        method.".format(
+                    "Error {}, this model is not fitted yet. Cal 'fit' with appropriate arguments before using this method.".format(
                         e
                     )
                 )
@@ -712,15 +706,15 @@ class SVPClassifier(BaseEstimator, ClassifierMixin):
                 - svptype, str {"fb", "dg", "sizectrl", "errorctrl"}
                     Type of set-valued predictor.
                 - beta, int
-                    Beta parameter in case of svptype="fb"
+                    Beta parameter in case of svptype="fb".
                 - delta, float
-                    Float parameter in case of svptype="dg"
+                    Float parameter in case of svptype="dg".
                 - gamma, float
-                    Float parameter in case of svptype="dg"
+                    Float parameter in case of svptype="dg".
                 - size, int
-                    Size parameter in case of svptype="sizectrl"
+                    Size parameter in case of svptype="sizectrl".
                 - error, float
-                    Error parameter in case of svptype="errorctrl"
+                    Error parameter in case of svptype="errorctrl".
 
         Returns
         -------
@@ -734,44 +728,44 @@ class SVPClassifier(BaseEstimator, ClassifierMixin):
         start_time = time.time()
         # process params
         if type(params["c"]) != int:
-            raise ValueError(
+            raise TypeError(
                 "Invalid representation complexity {0}. Must be integer.".format(
                     params["c"]
                 )
             )
         # c must be K in case of no hierarchy
         if self.hierarchy == "none" and params["c"] < len(self.classes_):
-            raise ValueError(
+            raise TypeError(
                 "Representation complexity {0} must be K in case of no hierarchy!".format(
                     params["c"]
                 )
             )
         if params["svptype"] == "fb":
             if type(params["beta"]) != int:
-                raise ValueError(
+                raise TypeError(
                     "Invalid beta {0}. Must be positive integer.".format(params["beta"])
                 )
         elif params["svptype"] == "dg":
             if type(params["gamma"]) != float and type(params["delta"]) != float:
-                raise ValueError(
+                raise TypeError(
                     "Invalid delta {0} or gamma {1}. Must be positive float.".format(
                         params["delta"], params["gamma"]
                     )
                 )
         elif params["svptype"] == "sizectrl":
             if type(params["size"]) != int:
-                raise ValueError(
+                raise TypeError(
                     "Invalid size {0}. Must be positive integer.".format(params["size"])
                 )
         elif params["svptype"] == "errorctrl":
             if type(params["error"]) != float:
-                raise ValueError(
+                raise TypeError(
                     "Invalid error {0}. Must be a real number in [0,1].".format(
                         params["error"]
                     )
                 )
         else:
-            raise ValueError(
+            raise TypeError(
                 "Invalid SVP type {0}! Valid options: {fb, dg, sizectrl, errorctrl}.".format(
                     params["svptype"]
                 )
@@ -780,9 +774,8 @@ class SVPClassifier(BaseEstimator, ClassifierMixin):
         if not hasattr(self.estimator, "predict_proba"):
             # check whether the base estimator supports class scores
             if not hasattr(self.estimator, "decision_function"):
-                raise NotFittedError(
-                    "{0} does not support \
-                         probabilistic predictions nor scores.".format(
+                raise RuntimeError(
+                    "{0} does not support probabilistic predictions nor scores.".format(
                         self.estimator
                     )
                 )
@@ -823,9 +816,7 @@ class SVPClassifier(BaseEstimator, ClassifierMixin):
                     o = [self.flabel_encoder_.inverse_transform(p) for p in o]
         except NotFittedError as e:
             raise NotFittedError(
-                "Error {}, this model is not fitted yet. Cal 'fit' \
-                    with appropriate arguments before using this \
-                    method.".format(
+                "Error {}, this model is not fitted yet. Cal 'fit' with appropriate arguments before using this method.".format(
                     e
                 )
             )
@@ -1113,9 +1104,7 @@ class SVPClassifier(BaseEstimator, ClassifierMixin):
             preds = self.predict(X)
         except NotFittedError as e:
             raise NotFittedError(
-                "Error {}, this model is not fitted yet. Cal 'fit' \
-                    with appropriate arguments before using this \
-                    method.".format(
+                "Error {}, this model is not fitted yet. Cal 'fit' with appropriate arguments before using this method.".format(
                     e
                 )
             )
@@ -1147,7 +1136,7 @@ class SVPClassifier(BaseEstimator, ClassifierMixin):
         """
         # check input and outputs
         if self.hierarchy == "none":
-            raise NotFittedError(
+            raise RuntimeError(
                 "Method 'score_nodes' is only supported for hierarchical classifiers!"
             )
         X, y = check_X_y(X, y, multi_output=False)
@@ -1178,9 +1167,7 @@ class SVPClassifier(BaseEstimator, ClassifierMixin):
                         score_dict[node["lbl"]] = acc
         except NotFittedError as e:
             raise NotFittedError(
-                "Error {}, this model is not fitted yet. Cal 'fit' \
-                    with appropriate arguments before using this \
-                    method.".format(
+                "Error {}, this model is not fitted yet. Cal 'fit' with appropriate arguments before using this method.".format(
                     e
                 )
             )
